@@ -24,13 +24,21 @@
 
 #include <panel-applet.h>
 #include <fcntl.h>
+#ifdef HAVE_PTY_H
 #include <pty.h>
+#endif
 #include <sys/poll.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <libxml/tree.h>
 #include <glade/glade.h>
 
+#ifdef __FreeBSD__
+#include <sys/ioctl.h>
+#include <termios.h>
+#include <libutil.h>
+#endif
+
 #include "modem-applet.h"
 
 #define MODEM_APPLET_GET_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TYPE_MODEM_APPLET, ModemAppletPrivate))
